(this["webpackJsonp@dagit/app"]=this["webpackJsonp@dagit/app"]||[]).push([[9],{1053:function(e,n,t){"use strict";t.r(n),t.d(n,"FeatureFlagsRoot",(function(){return l}));var c=t(19),i=t(15),u=t(27),o=t(0),s=t(562),a=t(39),r=t(1),l=function(){var e=o.useState(Object(a.j)()),n=Object(i.a)(e,2),t=n[0],l=n[1];o.useEffect((function(){Object(a.l)(t)})),Object(s.a)("Feature Flags");var d=function(e){l(t.includes(e)?t.filter((function(n){return n!==e})):[].concat(Object(c.a)(t),[e]))};return Object(r.jsxs)("div",{style:{padding:30,paddingTop:0},children:[Object(r.jsx)("h4",{children:"Experimental Features"}),Object(r.jsx)("div",{children:Object(r.jsx)(u.d,{label:"Debug Console Logging",checked:t.includes(a.b.DebugConsoleLogging),onChange:function(){return d(a.b.DebugConsoleLogging)}})}),Object(r.jsx)("div",{children:Object(r.jsx)(u.d,{label:"Pipeline name + mode tuples",checked:t.includes(a.b.PipelineModeTuples),onChange:function(){return d(a.b.PipelineModeTuples)}})})]})};n.default=l},562:function(e,n,t){"use strict";t.d(n,"a",(function(){return i}));var c=t(0),i=function(e){c.useEffect((function(){var n=document.title;return document.title=e,function(){document.title=n}}),[e])}}}]);
//# sourceMappingURL=9.ffa8558d.chunk.js.map